@@ -1,8 +1,9 @@
 package ShardedKV::Continuum::Ketama;
 {
-  $ShardedKV::Continuum::Ketama::VERSION = '0.01';
+  $ShardedKV::Continuum::Ketama::VERSION = '0.02';
 }
 use Moose;
+# ABSTRACT: Continuum implementation based on ketama consistent hashing
 use Algorithm::ConsistentHash::Ketama;
 use JSON::XS qw(encode_json decode_json);
 
@@ -86,12 +87,18 @@ sub _make_ketama {
 no Moose;
 __PACKAGE__->meta->make_immutable;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
 ShardedKV::Continuum::Ketama - Continuum implementation based on ketama consistent hashing
 
+=head1 VERSION
+
+version 0.02
+
 =head1 SYNOPSIS
 
   use ShardedKV;
@@ -110,18 +117,45 @@ See C<Algorithm::ConsistentHash::Ketama>.
 
 =head1 SEE ALSO
 
-L<ShardedKV>, L<ShardedKV::Continuum>
+=over 4
 
-=head1 AUTHOR
+=item *
 
-Steffen Mueller E<lt>smueller@cpan.orgE<gt>
+L<ShardedKV>
+
+=item *
+
+L<ShardedKV::Continuum>
+
+=item *
+
+L<Algorithm::ConsistentHash::Ketama>
+
+=back
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Steffen Mueller <smueller@cpan.org>
+
+=item *
+
+Nick Perez <nperez@cpan.org>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2012 by Steffen Mueller
+This software is copyright (c) 2012 by Steffen Mueller.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.1 or,
-at your option, any later version of Perl 5 you may have available.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
