@@ -1,8 +1,9 @@
 package ShardedKV::Storage::Redis::String;
 {
-  $ShardedKV::Storage::Redis::String::VERSION = '0.01';
+  $ShardedKV::Storage::Redis::String::VERSION = '0.02';
 }
 use Moose;
+# ABSTRACT: Storing simple string values in Redis
 use parent 'ShardedKV::Storage::Redis';
 use Encode;
 use Redis;
@@ -28,12 +29,18 @@ sub set {
 no Moose;
 __PACKAGE__->meta->make_immutable;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
 ShardedKV::Storage::Redis::String - Storing simple string values in Redis
 
+=head1 VERSION
+
+version 0.02
+
 =head1 SYNOPSIS
 
   use ShardedKV;
@@ -61,20 +68,49 @@ actually scalar references to strings.
 
 =head1 SEE ALSO
 
-L<ShardedKV>, L<ShardedKV::Storage>,
-L<ShardedKV::Storage::Redis>,
+=over 4
+
+=item *
+
+L<ShardedKV>
+
+=item *
+
+L<ShardedKV::Storage>
+
+=item *
+
+L<ShardedKV::Storage::Redis>
+
+=item *
+
 L<ShardedKV::Storage::Redis::Hash>
 
-=head1 AUTHOR
+=back
 
-Steffen Mueller E<lt>smueller@cpan.orgE<gt>
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Steffen Mueller <smueller@cpan.org>
+
+=item *
+
+Nick Perez <nperez@cpan.org>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2012 by Steffen Mueller
+This software is copyright (c) 2012 by Steffen Mueller.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.1 or,
-at your option, any later version of Perl 5 you may have available.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
